
import React, { useState, useEffect } from "react";
import { Card } from "@/components/ui/card";
import { toast } from "sonner";
import { loadStripe } from "@stripe/stripe-js";
import {
  Form,
} from "@/components/ui/form";
import { useForm } from "react-hook-form";
import { z } from "zod";
import { zodResolver } from "@hookform/resolvers/zod";
import PriceDisplay from "./PriceDisplay";
import BillingDetailsForm from "./BillingDetailsForm";
import PaymentOptions from "./PaymentOptions";
import PaymentPlanOptions, { PaymentPlan } from "./PaymentPlanOptions";

// Initialize Stripe only once
const stripePromise = loadStripe("pk_test_your_publishable_key");

const formSchema = z.object({
  email: z.string().email("Bitte gib eine gültige E-Mail-Adresse ein"),
  firstName: z.string().min(1, "Vorname ist erforderlich"),
  lastName: z.string().min(1, "Nachname ist erforderlich"),
  street: z.string().min(1, "Straße und Hausnummer sind erforderlich"),
  city: z.string().optional(),
  postalCode: z.string().min(1, "Postleitzahl ist erforderlich"),
  country: z.string().min(1, "Land ist erforderlich"),
  state: z.string().optional(),
  paymentPlan: z.enum(['einmal', 'raten']).default('einmal'),
  agreeTerms: z.boolean().refine(val => val === true, {
    message: "Du musst den AGB zustimmen, um fortzufahren"
  })
});

const CheckoutForm = () => {
  const [loading, setLoading] = useState(false);
  const [paymentRequestSupported, setPaymentRequestSupported] = useState(false);
  const [selectedPlan, setSelectedPlan] = useState<PaymentPlan>('einmal');
  
  const form = useForm<z.infer<typeof formSchema>>({
    resolver: zodResolver(formSchema),
    defaultValues: {
      email: "",
      firstName: "",
      lastName: "",
      street: "",
      city: "",
      postalCode: "",
      country: "Deutschland",
      state: "",
      paymentPlan: "einmal",
      agreeTerms: false
    },
  });

  useEffect(() => {
    // Check for payment request support once
    const checkPaymentRequestSupport = async () => {
      const stripe = await stripePromise;
      if (!stripe) return;
      
      const paymentRequest = stripe.paymentRequest({
        country: 'DE',
        currency: 'eur',
        total: {
          label: 'Fit 4 Dienst Challenge',
          amount: selectedPlan === 'einmal' ? 69700 : 35000, // Adjust amount based on selected plan
        },
        requestPayerName: true,
        requestPayerEmail: true,
      });
      
      const result = await paymentRequest.canMakePayment();
      setPaymentRequestSupported(!!result);
    };
    
    checkPaymentRequestSupport();
  }, [selectedPlan]);

  const handlePaymentRequestButton = async () => {
    setLoading(true);
    
    try {
      const stripe = await stripePromise;
      if (!stripe) {
        throw new Error("Stripe konnte nicht geladen werden");
      }
      
      const paymentRequest = stripe.paymentRequest({
        country: 'DE',
        currency: 'eur',
        total: {
          label: 'Fit 4 Dienst Challenge',
          amount: selectedPlan === 'einmal' ? 69700 : 35000,
        },
        requestPayerName: true,
        requestPayerEmail: true,
      });
      
      paymentRequest.on('paymentmethod', async (ev) => {
        const response = await fetch("/api/create-checkout-session", {
          method: "POST",
          headers: {
            "Content-Type": "application/json",
          },
          body: JSON.stringify({ 
            email: ev.payerEmail,
            name: ev.payerName,
            paymentMethodId: ev.paymentMethod.id,
            product: "challenge",
            paymentPlan: selectedPlan
          }),
        });
        
        const session = await response.json();
        
        if (session.error) {
          ev.complete('fail');
          toast.error("Es ist ein Fehler aufgetreten. Bitte versuche es erneut.");
        } else {
          ev.complete('success');
          if (session.requires_action) {
            const { error } = await stripe.confirmCardPayment(session.client_secret);
            if (error) {
              toast.error("Zahlung fehlgeschlagen. Bitte versuche es erneut.");
            } else {
              window.location.href = "/erfolg";
            }
          } else {
            window.location.href = "/erfolg";
          }
        }
      });
      
      paymentRequest.on('cancel', () => {
        setLoading(false);
      });
      
      paymentRequest.show();
    } catch (err) {
      toast.error("Es ist ein Fehler aufgetreten. Bitte versuche es erneut.");
      console.error("Payment request error:", err);
      setLoading(false);
    }
  };

  const handlePlanChange = (plan: PaymentPlan) => {
    setSelectedPlan(plan);
    console.log(`Payment plan changed to: ${plan}`);
  };

  return (
    <div className="checkout__form-container sticky top-24">
      <Card className="checkout__form p-6 md:p-8 shadow-lg border-0 bg-white rounded-xl">
        {/* Single instance of PriceDisplay component */}
        <PriceDisplay selectedPlan={selectedPlan} />
        
        <Form {...form}>
          <form onSubmit={form.handleSubmit(() => {})} className="space-y-6">
            {/* Single instance of BillingDetailsForm */}
            <BillingDetailsForm />
            
            {/* New PaymentPlanOptions component */}
            <PaymentPlanOptions onPlanChange={handlePlanChange} />
            
            {/* Single instance of PaymentOptions */}
            <PaymentOptions 
              loading={loading}
              paymentRequestSupported={paymentRequestSupported}
              onPaymentRequestButton={handlePaymentRequestButton}
              selectedPlan={selectedPlan}
            />
          </form>
        </Form>
      </Card>
    </div>
  );
};

export default CheckoutForm;
